@@ -190,9 +190,7 @@ static void read_rc_file_compiled()
         int rcode = saphire_load_obj(rc_fname
             , pipeout, pipein, STDERR_FILENO, NULL);
         saphire_sweep();
-        sRFd_delete(pipein);
         sWFd_flash(pipeout);
-        sWFd_delete(pipeout);
 
         if(rcode < 0) {
             fprintf(stderr, "%s\n", string_c_str(gErrMsg));
@@ -212,9 +210,7 @@ static void read_rc_file_compiled()
         int rcode = saphire_load_obj(rc_fname
             , pipeout, pipein, STDERR_FILENO, NULL);
         saphire_sweep();
-        sRFd_delete(pipein);
         sWFd_flash(pipeout);
-        sWFd_delete(pipeout);
         if(rcode < 0) {
             fprintf(stderr, "%s\n", string_c_str(gErrMsg));
             exit(1);
@@ -463,9 +459,7 @@ static void init_hooks()
     sWFd* pipeout = sWFd_new(STDOUT_FILENO);
     int rcode = saphire_shell(" def mcd_hook { true }; def atexit_hook { true }; def activate_hook { true }; def cursor_move_hook { true }; def cmdline_hook { true }", NULL, pipeout, pipein, STDERR_FILENO);
     saphire_sweep();
-    sRFd_delete(pipein);
     sWFd_flash(pipeout);
-    sWFd_delete(pipeout);
 
 }
 
@@ -836,7 +830,7 @@ int main(int argc, char* argv[])
 #endif
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.3.3", 1);
+    setenv("VERSION", "4.3.5", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -1036,7 +1030,6 @@ int main(int argc, char* argv[])
             sRFd* rfd = sRFd_new(0);
             saphire_shell3(ret, " pidof mfiler3", "pidof mfiler3", rfd);
             saphire_sweep();
-            sRFd_delete(rfd);
 
             char* p = string_c_str(ret);
             int pid = 0;
@@ -1303,9 +1296,7 @@ int main(int argc, char* argv[])
                 sWFd* pipeout = sWFd_new(STDOUT_FILENO);
                 int rcode = saphire_shell(buf + 1, "mfiler3 -e", pipeout, pipein, STDERR_FILENO);
                 saphire_sweep();
-                sRFd_delete(pipein);
                 sWFd_flash(pipeout);
-                sWFd_delete(pipeout);
 
                 putp(tigetstr("rev"));
                 printf("HIT ANY KEY");
@@ -1334,7 +1325,6 @@ int main(int argc, char* argv[])
                 saphire_shell3(str, buf + 1, "mfiler3 -E");
                 saphire_sweep();
                 saphire_sweep();
-                sRFd_delete(rfd);
 
                 int pipe = open(pipe_name, O_WRONLY);
                 write(pipe, string_c_str(str), string_size(str) +1);
@@ -1354,7 +1344,6 @@ int main(int argc, char* argv[])
     sRFd* rfd = sRFd_new(0);
     saphire_shell3(ret, " pidof mfiler3", "clean mfiler3 sockets", rfd);
     saphire_sweep();
-    sRFd_delete(rfd);
 
     DIR* dir = opendir(gTempDir);
     if(dir == NULL) {
@@ -1407,9 +1396,7 @@ int main(int argc, char* argv[])
     sWFd* pipeout = sWFd_new(STDOUT_FILENO);
     int rcode = saphire_shell("atexit_hook", NULL, pipeout, pipein, STDERR_FILENO);
     saphire_sweep();
-    sRFd_delete(pipein);
     sWFd_flash(pipeout);
-    sWFd_delete(pipeout);
     saphire_kill_all_jobs();
 
     /// モジュール解放 ///
