@@ -137,8 +137,6 @@ void menu_input(sMenu* self, int meta, int key)
         int rcode = saphire_shell(item->mCmd, NULL, pipeout, pipein, STDERR_FILENO);
         saphire_sweep();
         sWFd_flash(pipeout);
-        sWFd_delete(pipeout);
-        sRFd_delete(pipein);
 
         mclear();
     }
@@ -162,8 +160,6 @@ void menu_input(sMenu* self, int meta, int key)
                 int rcode = saphire_shell(item->mCmd, NULL, pipeout, pipein, STDERR_FILENO);
                 saphire_sweep();
                 sWFd_flash(pipeout);
-                sWFd_delete(pipeout);
-                sRFd_delete(pipein);
             }
         }
         
